==> gcjwebplugin_0.3.2.orig.tar.gz: gcjwebplugin-0.3.2/tests/TestApplet.java <==
import java.applet.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

public class TestApplet extends Applet
{
  Label l = new Label ("Label: LEFT");
  Button b = new Button ("Change Message");
  Button c = new Button ("Done");
  Panel p = new Panel();

  int alignment = Label.LEFT;
  int last;

  public void init()
  {
    System.err.println ("init()");
    l.setAlignment (Label.LEFT);

    b.addActionListener (new ActionListener ()
      {
        public void actionPerformed (ActionEvent e)
        {
          switch (alignment)
            {
            case Label.LEFT:
              alignment = Label.CENTER;
              l.setText ("Label: CENTER");
              l.setAlignment (alignment);
              last = Label.LEFT;
              break;
            case Label.CENTER:
              if (last == Label.LEFT)
                {
                  alignment = Label.RIGHT;
                  l.setText ("Label: RIGHT");
                  l.setAlignment (alignment);
                }
              else
                {
                  alignment = Label.LEFT;
                  l.setText ("Label: LEFT");
                  l.setAlignment (alignment);
                }
              break;
            case Label.RIGHT:
              alignment = Label.CENTER;
              l.setText ("Label: CENTER");
              l.setAlignment (alignment);
              last = Label.RIGHT;
              break;
            }
        }
      });

    c.addActionListener (new ActionListener ()
      {
        public void actionPerformed (ActionEvent e)
        {
          stop();
        }
      });

    setLayout (new GridLayout (0, 1));
    add (l);
    add (p);
    p.setLayout (new FlowLayout ());
    p.add (b);
    p.add (c);
  }

  public void start ()
  {
    System.err.println ("start()");
  }

  public void stop ()
  {
    System.err.println ("stop()");
  }

  
}

==> gcjwebplugin-0.9.0.tar.gz: gcjwebplugin-0.9.0/tests/TestApplet.java <==
import java.applet.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

public class TestApplet extends Applet
{
  Label l = new Label ("Label: LEFT");
  Button b = new Button ("Change Message");
  Button c = new Button ("Done");
  Panel p = new Panel();

  int alignment = Label.LEFT;
  int last;

  public void init()
  {
    System.out.println ("init()");
    l.setAlignment (Label.LEFT);

    b.addActionListener (new ActionListener ()
      {
        public void actionPerformed (ActionEvent e)
        {
          switch (alignment)
            {
            case Label.LEFT:
              alignment = Label.CENTER;
              l.setText ("Label: CENTER");
              l.setAlignment (alignment);
              last = Label.LEFT;
              break;
            case Label.CENTER:
              if (last == Label.LEFT)
                {
                  alignment = Label.RIGHT;
                  l.setText ("Label: RIGHT");
                  l.setAlignment (alignment);
                }
              else
                {
                  alignment = Label.LEFT;
                  l.setText ("Label: LEFT");
                  l.setAlignment (alignment);
                }
              break;
            case Label.RIGHT:
              alignment = Label.CENTER;
              l.setText ("Label: CENTER");
              l.setAlignment (alignment);
              last = Label.RIGHT;
              break;
            }
        }
      });

    c.addActionListener (new ActionListener ()
      {
        public void actionPerformed (ActionEvent e)
        {
          stop();
        }
      });

    setLayout (new GridLayout (0, 1));
    add (l);
    add (p);
    p.setLayout (new FlowLayout ());
    p.add (b);
    p.add (c);
  }

  public void start ()
  {
    System.out.println ("start()");
  }

  public void stop ()
  {
    System.out.println ("stop()");
  }

  
}
